@@ -10,9 +10,9 @@
 *
 * $Id: input.c,v 1.1 1996/12/10 18:41:26 jrh Exp $
 * $Log: input.c,v $
- * Revision 1.1  1996/12/10  18:41:26  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:41:26  jrh
+* Initial revision
+*
 *
 */
 #include<ctype.h>
@@ -28,8 +28,8 @@
 
 void relint(void);
 void assignBasisset(struct BASISSET *, char *);
-void changeBasissetPointers(struct BASISSET *, int, int, int);
-void changeExponentPointers(struct BASISSET *, int, int);
+void moveBasissetData(struct BASISSET *, struct BASISSET *, int, int);
+void changeExponentPointers(struct BASISSET *, long, int);
 void sortBasis(void);
 int  compar(const void *, const void *);
 void saveGeometry(void);
@@ -82,6 +82,7 @@ int input(int argc, char **argv)
   double aopt=0.0, bopt=0.0, copt=0.0, alphaopt=0.0, betaopt=0.0, gammaopt=0.0;
   register double e;
   size_t mna=20, mnn=60, mnh=50, mno=100, mnc=2000, mns=100, mnp=200;
+  long offset;
   int readNext, n=0, ncoeff=0, *help, shell, primitive;
   int pured=TRUE, puref=TRUE, pureg=TRUE, frac=FALSE;
   int namax=0;
@@ -403,11 +404,11 @@ int input(int argc, char **argv)
                 cmo=(double *)expmem(cmo, mnc, sizeof(double));
                 if (oldcmo != cmo)
                 {
-                  k=(char *)cmo-(char *)oldcmo;
+                  offset=(char *)cmo-(char *)oldcmo;
                   for (l=0; l<=i; l++)
                   {
-                    m=(int)orbitals[l].coeff+k;
-                    orbitals[l].coeff=(double *)m;
+                    w=(char *)orbitals[l].coeff+offset;
+                    orbitals[l].coeff=(double *)w;
                   }
                 }
               }
@@ -423,11 +424,11 @@ int input(int argc, char **argv)
                 cmo=(double *)expmem(cmo, mnc, sizeof(double));
                 if (oldcmo != cmo)
                 {
-                  k=(char *)cmo-(char *)oldcmo;
+                  offset=(char *)cmo-(char *)oldcmo;
                   for (l=0; l<=i; l++)
                   {
-                    m=(int)orbitals[l].coeff+k;
-                    orbitals[l].coeff=(double *)m;
+                    w=(char *)orbitals[l].coeff+offset;
+                    orbitals[l].coeff=(double *)w;
                   }
                 }
               }
@@ -511,7 +512,7 @@ int input(int argc, char **argv)
         {
           if (!strcmp(orbitals[j].symmetry, word))
           {
-            orbitals[j].occupation=2.0e0;
+            orbitals[j].occupation=2.0;
             if (--i == 0) break;
           }
         }
@@ -598,9 +599,9 @@ int input(int argc, char **argv)
         {
           mns+=100;
           oldbasisset=basisset;
-          basisset=(struct BASISSET *)expmem((void *)basisset, mns, sizeof(struct BASISSET));
-          if (basisset != oldbasisset)
-            changeBasissetPointers(basisset, basisset-oldbasisset, shell, na);
+          basisset=(struct BASISSET *)getmem(mns, sizeof(struct BASISSET));
+          moveBasissetData(basisset, oldbasisset, shell, na);
+	    fremem((void **)&oldbasisset);
         }
         basisset[shell-1].next=&basisset[shell];
       }
@@ -612,9 +613,11 @@ int input(int argc, char **argv)
         changeExponentPointers(basisset, exponents-oldexponents, shell);
       oldbasisset=basisset;
       if (shell > 0)
-        basisset=(struct BASISSET *)expmem((void *)basisset, shell, sizeof(struct BASISSET));
-      if (basisset != oldbasisset)
-        changeBasissetPointers(basisset, basisset-oldbasisset, shell, na);
+      {
+        basisset=(struct BASISSET *)getmem(shell, sizeof(struct BASISSET));
+        moveBasissetData(basisset, oldbasisset, shell, na);
+	  fremem((void **)&oldbasisset);
+	}
       if (debug == 2) wrbas(na);
       cnorm(na);
     }
@@ -666,8 +669,11 @@ int input(int argc, char **argv)
       if (basisset != NULL && !gaussian) sortBasis();
       if (orbitals != NULL && ncoeff != 0)
       {
-        modcmo(orbitals, pured, puref, pureg, na, nbasfu, gaussian);
-        fremem((void **)&cmo);
+        if (basisset != NULL)
+	  {
+	    modcmo(orbitals, pured, puref, pureg, na, nbasfu, gaussian);
+          fremem((void **)&cmo);
+	  }
       }
       if (a != 0.0) existsUnitCell=makeUnitCell(a, b, c, alpha, beta, gamma, frac);
 /*    if (na != namax && namax != 0) setGeometry(FALSE); */
@@ -775,18 +781,37 @@ void assignBasisset(struct BASISSET *basisset, char *label)
   }
 }
 
-void changeBasissetPointers(struct BASISSET *basisset, int offset, int shell, int na)
+void moveBasissetData(struct BASISSET *new, struct BASISSET *old, int shell,
+			    int na)
 {
+  register long offset;
   register int i;
+  register char *p;
 
-  for (i=0; i<shell; i++)
-    if (basisset[i].next != NULL) basisset[i].next+=offset;
-
+  offset=(char *)new-(char *)old;
   for (i=0; i<na; i++)
-    if (atoms[i].basis != NULL) atoms[i].basis+=offset;
+  {
+    if (atoms[i].basis != NULL)
+    {
+      p=(char *)atoms[i].basis+offset;
+	atoms[i].basis=(struct BASISSET *)p;
+    }
+  }
+  for (i=0; i<shell; i++)
+  {
+    new[i].first=old[i].first;
+    new[i].nprim=old[i].nprim;
+    new[i].ang=old[i].ang;
+    new[i].next=old[i].next;
+    if (new[i].next != NULL)
+    {
+	p=(char *)new[i].next+offset;
+	new[i].next=(struct BASISSET *)p;
+    }
+  }
 }
 
-void changeExponentPointers(struct BASISSET *basisset, int offset, int shell)
+void changeExponentPointers(struct BASISSET *basisset, long offset, int shell)
 {
   register int i;
 
