@@ -63,7 +63,7 @@ void main(int argc, char **argv)
   char emark[2][7] = {"0@  ~0", "0@  ~0"}, line[MAXLENLINE], *word;
   char *symbol;
   int freq=FALSE, gfprn=FALSE, opt=FALSE;
-  int nemark=0, ntmar, nout, na, ncent, nuc, mna=50;
+  int nemark=0, nout, na, ncent, nuc, mna=50;
   int etex;
   register double x, y, z;
   register int i, mak;
@@ -80,8 +80,9 @@ void main(int argc, char **argv)
   do
   {
     if (fgets(line, MAXLENLINE, file) == NULL) eof("noCoordinates", argv[1], 1);
-  } while (!strstr(line, TABMAR));
-  fgets(line, MAXLENLINE, file);
+/*} while (!strstr(line, TABMAR));
+  fgets(line, MAXLENLINE, file);*/
+  } while (strncmp(line, " #", 2));
   do
   {
     makeLower(line);
@@ -131,16 +132,16 @@ void main(int argc, char **argv)
 
 /* Load Title */
 
-  rewind(file);
-  ntmar=0;
+/*rewind(file);
+  int ntmar=0;
   while (ntmar != 3)
-  {
+  { */
     do
     {
       if (fgets(line, MAXLENLINE, file) == NULL) eof("noCoordinates", argv[1], 1);
     } while (!strstr(line, TABMAR));
-    ntmar++;
-  }
+/*  ntmar++;
+  } */
   fgets(line, MAXLENLINE, file);
   printf("$title\n%s", line);
 
@@ -302,7 +303,7 @@ void readBasis(FILE *file, int na)
       fgets(line, MAXLENLINE, file);
       if (line[49] != ' ') break;
       changeDs(line);
-      word=strchr(line, '.');
+      word=strchr(line, '.')-1;
       sscanf(word, "%12le%12le%12le%12le%12le", &ex[i], &scoeff[i],
 		 &pcoeff[i], &dcoeff[i], &fcoeff[i]);
       ex[i++]*=scalefactor;
@@ -384,6 +385,7 @@ void readMOs(FILE *file)
   while (fgets(line, MAXLENLINE, file))
   {
     makeLower(line);
+    if ((word=strrchr(line, '\n')) != NULL) *word='\0';
     if (strstr(line, "the electronic state") || strstr(line, " alpha deviation from unit magnitude")) break;
     if (strstr(line, "occupied") || strstr(line, "virtual"))
     {
@@ -418,7 +420,7 @@ void readMOs(FILE *file)
 	  }
 	}
       i++;
-      if (i > mno)
+      if (i >= mno)
       {
     	  mno+=20;
 	  symorb=(char *)expmem((void *)symorb, mno, 4*sizeof(char));
@@ -591,7 +593,7 @@ void readOpg(FILE *file, int na, int nemark, char *emark)
 {
   double *x, *y, *z, *gx, *gy, *gz;
   double energy, gnorm;
-  int cycle=1, mak=0, etex;
+  int cycle=0, mak=0, etex;
   char line[MAXLENLINE], *symbol;
   register int i, nuc;
 
@@ -604,7 +606,6 @@ void readOpg(FILE *file, int na, int nemark, char *emark)
   symbol=(char *)getmem(na, 3*sizeof(char));
 
   rewind(file);
-  printf("$grad\n");
   while (TRUE)
   {
     do
@@ -686,12 +687,12 @@ void readOpg(FILE *file, int na, int nemark, char *emark)
     strtok(NULL, " \t");
     strtok(NULL, " \t");
     gnorm=atof(strtok(NULL, " \t"));
+    if (cycle++) printf("$grad\n");
     printf("  cycle = %3d    SCF energy = %17.10f   |dE/xyz| = %9.6f\n", cycle, energy, gnorm);
     for (i=0; i<na; i++)
       printf("%22.14f%22.14f%22.14f  %s\n", x[i], y[i], z[i], &symbol[3*i]);
     for (i=0; i<na; i++)
       printf("%22.14e%22.14e%22.14e\n", gx[i], gy[i], gz[i]);
-    cycle++;
   }
 }
 
